@@ -1,17 +1,20 @@
-require "gruff/version"
+require 'gruff/version'
 
 # Extra full path added to fix loading errors on some installations.
 
 %w(
+  themes
   base
   area
   bar
-  line
+  bezier
+  bullet
   dot
-  pie
-  spider
+  line
   net
+  pie
   scatter
+  spider
   stacked_area
   stacked_bar
   side_stacked_bar
@@ -25,7 +28,5 @@ require "gruff/version"
   mini/pie
   mini/side_bar
 ).each do |filename|
-  require File.dirname(__FILE__) + "/gruff/#{filename}"
+  require "gruff/#{filename}"
 end
-
-# TODO bullet
