@@ -1,5 +1,5 @@
 require 'rubygems'
-require 'RMagick'
+require 'rmagick'
 require 'bigdecimal'
 
 require File.dirname(__FILE__) + '/deprecated'
@@ -117,6 +117,12 @@ module Gruff
     # a reader here.
     attr_reader :font
 
+    # Same as font but for the title.
+    attr_reader :title_font
+    
+    # Specifies whether to draw the title bolded or not.
+    attr_accessor :bold_title
+
     attr_accessor :font_color
 
     # Prevent drawing of line markers
@@ -249,6 +255,7 @@ module Gruff
 
       vera_font_path = File.expand_path('Vera.ttf', ENV['MAGICK_FONT_PATH'])
       @font = File.exists?(vera_font_path) ? vera_font_path : nil
+      @bold_title = true
 
       @marker_font_size = 21.0
       @legend_font_size = 20.0
@@ -290,6 +297,11 @@ module Gruff
       @d.font = @font
     end
 
+    # Sets the title font to the font at +font_path+
+    def title_font=(font_path)
+      @title_font = font_path
+    end
+
     # Add a color to the list of available colors for lines.
     #
     # Example:
@@ -521,8 +533,8 @@ module Gruff
     def setup_graph_measurements
       @marker_caps_height = @hide_line_markers ? 0 :
           calculate_caps_height(@marker_font_size)
-      @title_caps_height = @hide_title ? 0 :
-          calculate_caps_height(@title_font_size)
+      @title_caps_height = (@hide_title || @title.nil?) ? 0 :
+          calculate_caps_height(@title_font_size) * @title.lines.to_a.size
       @legend_caps_height = @hide_legend ? 0 :
           calculate_caps_height(@legend_font_size)
 
@@ -799,10 +811,10 @@ module Gruff
       return if (@hide_title || @title.nil?)
 
       @d.fill = @font_color
-      @d.font = @font if @font
+      @d.font = @title_font || @font if @title_font || @font
       @d.stroke('transparent')
       @d.pointsize = scale_fontsize(@title_font_size)
-      @d.font_weight = BoldWeight
+      @d.font_weight = if @bold_title then BoldWeight else NormalWeight end
       @d.gravity = NorthGravity
       @d = @d.annotate_scaled(@base_image,
                               @raw_columns, 1.0,
@@ -1123,6 +1135,11 @@ module Gruff
       @d.get_type_metrics(@base_image, text.to_s).width
     end
 
+    # Used for degree => radian conversions
+    def deg2rad(angle)
+      angle * (Math::PI/180.0)
+    end
+
   end # Gruff::Base
 
   class IncorrectNumberOfDatasetsException < StandardError;
